@@ -17,15 +17,17 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if defined(ATK_DISABLE_SINGLE_INCLUDES) && !defined (__ATK_H_INSIDE__) && !defined (ATK_COMPILATION)
+#error "Only <atk/atk.h> can be included directly."
+#endif
+
 #ifndef __ATK_IMAGE_H__
 #define __ATK_IMAGE_H__
 
 #include <atk/atkobject.h>
 #include <atk/atkutil.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 /*
  * The AtkImage interface should be supported by any object that has an 
@@ -57,6 +59,10 @@ struct _AtkImageIface
                                                    gint                  *height);
   gboolean              ( *set_image_description) (AtkImage              *image,
                                                    const gchar           *description);
+  G_CONST_RETURN gchar* ( *get_image_locale)      (AtkImage              *image);
+
+  AtkFunction           pad1;
+	
 };
 
 GType  atk_image_get_type             (void);
@@ -74,7 +80,8 @@ void     atk_image_get_image_position    (AtkImage	     *image,
 					  gint	             *y,
     					  AtkCoordType	     coord_type);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_CONST_RETURN gchar* atk_image_get_image_locale (AtkImage   *image);
+
+G_END_DECLS
+
 #endif /* __ATK_IMAGE_H__ */
